/*  Filename:  TabLangService.js
 * $Revision: 1.1 $
 *     $Date: 2008/08/04 22:50:22 $
 *
 * TabLang service XPCOM component to share functionality between windows.
 * This file creates only XPCOM component skeleton.
 * All TabLang-related code is in chrome/content/TabLang.js
 * 
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is TabLang extension for Mozilla Firefox.
 *
 * The Initial Developer of the Original Code is Andrey Lokot.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Andrey Lokot <crazy-eye@yandex.ru>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// This  implementation of core functionality of XPCOM component is based on
// "How to Build an XPCOM Component in Javascript" MDC article. See
// http://developer.mozilla.org/en/docs/How_to_Build_an_XPCOM_Component_in_Javascript
// for details and comments on this code

// Including "chrome/content/TabLang.js" where actual implementation goes
Components.classes["@mozilla.org/moz/jssubscript-loader;1"]
	.getService(Components.interfaces.mozIJSSubScriptLoader)
	.loadSubScript("chrome://tablang/content/TabLang.js");

const CLASS_ID = Components.ID("{FEA9CCED-268A-43f6-B373-AD4BADB5E559}");
const CLASS_NAME = "TabLang service to share functionality between windows";
const CONTRACT_ID = "tablang@mozdev.org/tablangservice;1";

function TabLangService() {
	this.wrappedJSObject = this;
	// Initializing TabLang-related properties.
	// initTabLangService() is implemented in chrome/content/TabLang.js
	initTabLangService(this);
}

TabLangService.prototype.QueryInterface = function(aIID) {
	if (!aIID.equals(Components.interfaces.nsISupports))
		throw Components.results.NS_ERROR_NO_INTERFACE;
	return this;
};

var TabLangServiceFactory = {
	createInstance: function (aOuter, aIID)
	{
		if (aOuter != null)
			throw Components.results.NS_ERROR_NO_AGGREGATION;
		return (new TabLangService()).QueryInterface(aIID);
	}
};

var TabLangServiceModule = {
	registerSelf: function(aCompMgr, aFileSpec, aLocation, aType)
	{
		aCompMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar)
				.registerFactoryLocation(CLASS_ID, CLASS_NAME, CONTRACT_ID, aFileSpec, aLocation, aType);
	},
	unregisterSelf: function(aCompMgr, aLocation, aType)
	{
		aCompMgr.QueryInterface(Components.interfaces.nsIComponentRegistrar)
				.unregisterFactoryLocation(CLASS_ID, aLocation);        
	},
	getClassObject: function(aCompMgr, aCID, aIID)
	{
		if (!aIID.equals(Components.interfaces.nsIFactory))
			throw Components.results.NS_ERROR_NOT_IMPLEMENTED;
		if (aCID.equals(CLASS_ID))
			return TabLangServiceFactory;
		throw Components.results.NS_ERROR_NO_INTERFACE;
	},
	canUnload: function(aCompMgr) { return true; }
};

function NSGetModule(aCompMgr, aFileSpec) { return TabLangServiceModule; }
